@@ -36,7 +36,7 @@ def show_grid(records):
                 export_excel=True,
                 theme='ag-theme-balham',
                 show_toggle_delete=True,
-                # columns_fit='auto',
+                columns_fit='auto',
                 index=False,
                 keep_multiindex=False)
 
